Learn R Programming

leakr (version 0.1.0)

detector_registry: Registry-based Detector System

Description

This section of the package manages a registry for various data leakage detectors. Detectors are stored in the .detector_registry environment and are accessible by name. The system allows for easy registration of detectors, providing their descriptions and registration times. Detectors can be queried by name or listed.

Usage

.detector_registry

Arguments

Format

An object of class environment of length 2.