Learn R Programming

leakr (version 0.1.0)

format_detector_name: Format detector names for display.

Description

Format detector names by converting them to title case and separating words by spaces.

Usage

format_detector_name(detector_name)

Value

A title-cased, space-separated string.

Arguments

detector_name

A string to format, typically a detector name with underscores.