Learn R Programming

leakr (version 0.1.0)

get_detector_info: Get detector information

Description

Retrieves information about detectors, optionally filtering by the detector name.

Usage

get_detector_info(name = NULL)

Value

A list with detector information, including description and registration date.

Arguments

name

Optional detector name. If NULL, returns info for all detectors.

Examples

Run this code
# Get information for all detectors
get_detector_info()

# Get information for specific detectors that actually exist
get_detector_info("file_format")

Run the code above in your browser using DataLab