Learn R Programming

leakr (version 0.1.0)

list_registered_detectors: List Registered Detectors

Description

Returns the names of all detectors currently registered in the system. This is useful for checking which detectors are available.

Usage

list_registered_detectors()

Arguments

Value

A character vector containing the names of all registered detectors.

Examples

Run this code
list_registered_detectors()

Run the code above in your browser using DataLab