Learn R Programming

leakr (version 0.1.0)

run_detectors: Run multiple detectors on audit data

Description

This function runs multiple leakage detectors on the provided audit data and returns the results for each detector.

Usage

run_detectors(detectors, audit_data, config)

Value

A list where each element contains the results of running a detector. If a detector fails, an error message is included in the result.

Arguments

detectors

A list of detector configurations. Each detector can be either a function or an object that contains a func field with the detector function.

audit_data

A data.frame, tibble, or data.table to audit.

config

A list of configuration settings to be passed to each detector.

Examples

Run this code
if (FALSE) {
detectors <- list(
  temporal = list(func = temporal_detector_func),
  train_test = new_train_test_detector()
)
results <- run_detectors(detectors, audit_data = iris, config = list(sample_size = 50000))
}

Run the code above in your browser using DataLab