powered by
Retrieves information about detectors, optionally filtering by the detector name.
get_detector_info(name = NULL)
A list with detector information, including description and registration date.
Optional detector name. If NULL, returns info for all detectors.
# Get information for all detectors get_detector_info() # Get information for specific detectors that actually exist get_detector_info("file_format")
Run the code above in your browser using DataLab