import_parquet: Import Parquet files
Description
Import and process Parquet files into a standardized data.frame.
Usage
import_parquet(file_path, verbose = FALSE, ...)
Value
A data.frame with the content from the Parquet file.
Arguments
- file_path
Path to the Parquet file.
- verbose
Logical flag indicating whether to show progress messages (default is FALSE).
- ...
Additional arguments passed to arrow::read_parquet().