leakr_summarise: Enhanced summarise with better formatting
Description
This function provides a formatted summary of the leakage audit report. It displays
a summary of the leakage issues, including the severity and top issues detected.
Optionally, it can also display configuration details used for the audit.
An invisible data.frame summarizing the top n issues detected.
Arguments
report
A leakr_report object from leakr_audit().
top_n
Maximum number of issues to display in the summary. Defaults to 10.
show_config
Whether to display the configuration details used for the audit. Defaults to FALSE.
config
(Optional) A configuration list. This argument is not used directly in the function,
but is referenced in the report metadata. Defaults to NULL.
audit_data
(Optional) The data used for auditing. This argument is not used directly in the function,
but is part of the report metadata. Defaults to NULL.
detectors
(Optional) A vector of detectors used for the audit. This argument is not used directly in
the function but is part of the report metadata. Defaults to NULL.
libname
(Optional) The name of the library. This is included for internal package functionality.
pkgname
(Optional) The name of the package. This is included for internal package functionality.