powered by
Returns the names of all detectors currently registered in the system. This is useful for checking which detectors are available.
list_registered_detectors()
A character vector containing the names of all registered detectors.
Run the code above in your browser using DataLab